maite.protocols.object\_detection.ObjectDetectionTarget
=======================================================

.. currentmodule:: maite.protocols.object_detection

.. autoclass:: ObjectDetectionTarget